@@ -18,16 +18,23 @@ function log() {
 source /etc/profile
 log "Refreshing modules..."
 module purge
-module load python/3.7
-module load pytorch/1.7
+GIT_URL=$1
+ENTRYPOINT=$2
+HASH_COMMIT=$3
+EXTRA_MODULES=$(echo $4 | tr "@" " ")
+
+for MODULE in $EXTRA_MODULES
+do
+	module load $MODULE
+done
 
 FOLDER=$SLURM_TMPDIR/src/
 
-log "downloading source code from $1 to $FOLDER"
+log "downloading source code from $GIT_URL to $FOLDER"
 # https://stackoverflow.com/questions/7772190/passing-ssh-options-to-git-clone/28527476#28527476
-GIT_SSH_COMMAND="ssh -o UserKnownHostsFile=/dev/null -o StrictHostKeyChecking=no" git clone $1 $FOLDER/
+GIT_SSH_COMMAND="ssh -o UserKnownHostsFile=/dev/null -o StrictHostKeyChecking=no" git clone $GIT_URL $FOLDER/
 cd $FOLDER || exit
-git checkout $3
+git checkout $HASH_COMMIT
 log "pwd is now $(pwd)"
 
 # Set up virtualenv in $SLURM_TMPDIR. Will get blown up at job end.
@@ -43,4 +50,4 @@ python3 -m pip install --upgrade -r "requirements.txt" --exists-action w -f http
 
 export XLA_FLAGS=--xla_gpu_cuda_data_dir=/cvmfs/ai.mila.quebec/apps/x86_64/common/cuda/10.1/
 # TODO: the client should send the experiment_buddy version to avoid issues
-wandb agent "$2"
+wandb agent "$ENTRYPOINT"
